# -*- coding: utf-8 -*-
"""
Created on Thu Jan  5 20:55:26 2017

@author: Young Ju Kim
"""

import pandas as pd
from datetime import datetime

import psycopg2 as pg
import sqlalchemy as sa
#import ibm_db
import ibm_db_sa
import cx_Oracle as co
import pymysql

from unipy.util.wrapper import time_profiler

__all__ = ['from_OracleSQL']

@time_profiler
def from_OracleSQL(query, h=None, port=None, db=None, u=None, p=None):

    print('Using OracleDB')

    # DB Connection
    dnsStr = co.makedsn(h, str(port), db)
    dnsStr = dnsStr.replace('SID', 'SERVICE_NAME')
    conn = co.connect(u, p, dnsStr)

    # Get a DataFrame
    query_result = pd.read_sql(query, conn)

    # Close Connection
    conn.close()

    return query_result




# -*- coding: utf-8 -*-
"""
Created on Thu Jan  5 20:55:26 2017

@author: Young Ju Kim
"""

import pandas as pd
from datetime import datetime

import psycopg2 as pg
import sqlalchemy as sa
#import ibm_db
import ibm_db_sa
#import cx_Oracle as co
import pymysql

from unipy.util.wrapper import time_profiler

__all__ = ['from_PostgreSQL',
           'from_DB2SQL',
           'from_MariaDB']

@time_profiler
def from_PostgreSQL(query, h=None, port=None, db=None, u=None, p=None):

    print('Using PostgreSQL')

    # DB Connection
    conn = pg.connect(host=h, port=str(port), user=u, password=p)

    # Get a DataFrame
    query_result = pd.read_sql(query, conn)

    # Cloase Connection
    conn.close()

    return query_result


@time_profiler
def from_DB2SQL(query, h=None, port=None, db=None, u=None, p=None):

    print('Using IBM DB2')

    # DB Connection
    connStr = 'ibm_db_sa://{}:{}@{}:{}/{}'
    engine = sa.create_engine(connStr.format(u, p, h, str(port), db))
    conn = engine.connect()

    # Get a DataFrame
    execonn = engine.execute(query)

    query_result = pd.DataFrame(execonn.fetchall())
    query_result.columns = execonn.keys()

    # Close Connection
    conn.close()

    return query_result


@time_profiler
def from_MariaDB(query, h=None, port=None, db=None, u=None, p=None):

    print('Using MariaDB')

    # DB Connection
    conn = pymysql.connect(host=h, port=p, user=u, password=p, database=db)

    # Get a DataFrame
    query_result = pd.read_sql(query, conn)

    # Close Connection
    conn.close()

    return query_result



# -*- coding: utf-8 -*-
"""
Created on Thu Jan  5 20:55:26 2017

@author: Young Ju Kim
"""


from unipy_db.database import select_query
from unipy_db.database import insert_query

from unipy_db.database.select_query import *
from unipy_db.database.insert_query import *

__all__ = []
__all__ += select_query.__all__
__all__ += insert_query.__all__




# -*- coding: utf-8 -*-
"""
Created on Thu Jan  5 20:55:26 2017

@author: Young Ju Kim
"""

import pandas as pd

import psycopg2 as pg
import sqlalchemy as sa
# import ibm_db_sa

from unipy.util.wrapper import time_profiler

__all__ = ['to_MariaDB']

@time_profiler
def to_MariaDB(DataFrame, db=None, table=None, h=None, port=3306, u=None, p=None,
            if_exists='append'):

    print('Using MariaDB')

    # DB Connection
    connStr = 'mysql+pymysql://{}:{}@{}:{}/{}?charset=utf8'
    engine = sa.create_engine(connStr.format(u, p, h, str(port), db))

    # Get a DataFrame
    DataFrame.to_sql(con=engine, name=table, if_exists=if_exists,
                     index=False, chunksize=None)




#-*- coding: utf-8 -*-
"""
Created on 2017-01-05 20:55:26
Modified on 2017-06-26 02:36:25

@author: Young Ju Kim
"""

try:

    from setuptools import setup, find_packages

except ImportError:

    from distutils.core import setup, find_packages


import tarfile


def package_data_listup():

    filename = 'dataset/resources.gz/resources.tar.gz'
    tar = tarfile.open(filename)
    filelist = list(set(map(lambda x: x.split('/')[0], tar.getnames())))
    filelist.sort()
    return filelist


long_desc = """
This is made for some specific environment.
This contains codes for DataBases.
"""

setup(name='unipy_db',
      version='0.0.2',
      description='Useful tools for Data Scientists',
      long_description=long_desc,
      url='http://github.com/pydemia/unipy-db',
      author='Young Ju Kim',
      author_email='pydemia@gmail.com',
      license='MIT License',
      classifiers=[
            # How Mature: 3 - Alpha, 4 - Beta, 5 - Production/Stable
            'Development Status :: 4 - Beta',
            'Environment :: Console',
            'Programming Language :: Python :: 3.5',
            'Operating System :: OS Independent',
            'Intended Audience :: End Users/Desktop',
            'Intended Audience :: Developers',
            'Intended Audience :: Science/Research',
            'Natural Language :: English',
            ],
      packages=find_packages(exclude=['contrib', 'docs', 'tests']),
      install_requires=[
                        'pandas>=0.20.2',
                        'pymysql',
                        'psycopg2==2.7.1',
                        'sqlalchemy>=1.1.11',
                        'ibm_db_sa>=0.3.3',
                        'cx_Oracle==5.3'
                        ],
      zip_safe=False,
      #package_data={'unipy': ['*.gz', 'dataset/resources.tar.gz']}
      )
